==> payara-embedded-all-5.2020.4-sources.jar: com/sun/enterprise/admin/util/CommandThreadPool.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2007-2016 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2018] Payara Foundation and/or affiliates

package com.sun.enterprise.admin.util;

import com.sun.enterprise.config.serverbeans.Config;
import com.sun.enterprise.config.serverbeans.Domain;
import com.sun.enterprise.config.serverbeans.ServerTags;
import org.glassfish.grizzly.config.dom.NetworkConfig;
import org.glassfish.grizzly.config.dom.NetworkListener;
import org.glassfish.api.StartupRunLevel;
import org.glassfish.api.admin.InstanceCommand;
import org.glassfish.api.admin.InstanceCommandResult;
import org.glassfish.api.admin.ServerEnvironment;

import org.jvnet.hk2.annotations.Service;
import org.glassfish.hk2.api.PostConstruct;
import org.glassfish.hk2.api.ServiceLocator;
import org.glassfish.hk2.runlevel.RunLevel;

import javax.inject.Inject;
import java.util.List;
import java.util.concurrent.*;
import java.util.logging.Logger;


/**
 * This singleton service creates and holds the command pool used to execute commands
 * @author Vijay Ramachandran
 */
@Service
@RunLevel(mode=RunLevel.RUNLEVEL_MODE_NON_VALIDATING,value=StartupRunLevel.VAL)
public class CommandThreadPool implements PostConstruct {

    @Inject
    private ServiceLocator habitat;

    @Inject
    private ServerEnvironment serverEnv;

    @Inject
    private Domain domain;

    @Inject
    private Logger logger;

    private ExecutorService svc = null;

    /**
     * Process the instance file if this is DAS and there are instances configured already in this domain
     */
    @Override
    public void postConstruct() {
        // If this is not the DAS, no need for this pool
        if(serverEnv.isInstance()) {
            return;
        }
        int poolSize = 5;
        Config svrConfig = domain.getConfigNamed("server-config");
        // I am doing this code instead of a simple svrConfig.getAdminListener() here because embedded tests are failing
        // during build; got to check the reason why later.
        if(svrConfig != null) {
            NetworkConfig nwc = svrConfig.getNetworkConfig();
            if (nwc != null) {
                List<NetworkListener> lss = nwc.getNetworkListeners().getNetworkListener();
                if ( (lss != null) && (!lss.isEmpty()) ) {
                    for (NetworkListener ls : lss) {
                        if (ServerTags.ADMIN_LISTENER_ID.equals(ls.getName()) && ls.findThreadPool() != null) {
                            poolSize = Integer.parseInt(ls.findThreadPool().getMaxThreadPoolSize());
                        }
                    }
                }
            }
        }
        svc = Executors.newFixedThreadPool(poolSize, new InstanceStateThreadFactory());
    }

    public Future<InstanceCommandResult> submitJob(InstanceCommand ice, InstanceCommandResult r) {
        FutureTask<InstanceCommandResult> t = new FutureTask<InstanceCommandResult>((Runnable)ice, r);
        return svc.submit(t, r);
    }

    private static class InstanceStateThreadFactory implements ThreadFactory {
        @Override
        public Thread newThread(Runnable runnableObj) {
            Thread t = new Thread(runnableObj);
            t.setDaemon(true);
            return t;
        }
    }
}

==> payara-embedded-all-6.2023.2-sources.jar: com/sun/enterprise/admin/util/CommandThreadPool.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2007-2016 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2018-2021] Payara Foundation and/or affiliates

package com.sun.enterprise.admin.util;

import com.sun.enterprise.config.serverbeans.Config;
import com.sun.enterprise.config.serverbeans.Domain;
import com.sun.enterprise.config.serverbeans.ServerTags;
import org.glassfish.grizzly.config.dom.NetworkConfig;
import org.glassfish.grizzly.config.dom.NetworkListener;
import org.glassfish.api.StartupRunLevel;
import org.glassfish.api.admin.InstanceCommand;
import org.glassfish.api.admin.InstanceCommandResult;
import org.glassfish.api.admin.ServerEnvironment;

import org.jvnet.hk2.annotations.Service;
import org.glassfish.hk2.api.PostConstruct;
import org.glassfish.hk2.api.ServiceLocator;
import org.glassfish.hk2.runlevel.RunLevel;

import jakarta.inject.Inject;
import java.util.List;
import java.util.concurrent.*;
import java.util.logging.Logger;


/**
 * This singleton service creates and holds the command pool used to execute commands
 * @author Vijay Ramachandran
 */
@Service
@RunLevel(mode=RunLevel.RUNLEVEL_MODE_NON_VALIDATING,value=StartupRunLevel.VAL)
public class CommandThreadPool implements PostConstruct {

    @Inject
    private ServiceLocator habitat;

    @Inject
    private ServerEnvironment serverEnv;

    @Inject
    private Domain domain;

    @Inject
    private Logger logger;

    private ExecutorService svc = null;

    /**
     * Process the instance file if this is DAS and there are instances configured already in this domain
     */
    @Override
    public void postConstruct() {
        // If this is not the DAS, no need for this pool
        if(serverEnv.isInstance()) {
            return;
        }
        int poolSize = 5;
        Config svrConfig = domain.getConfigNamed("server-config");
        // I am doing this code instead of a simple svrConfig.getAdminListener() here because embedded tests are failing
        // during build; got to check the reason why later.
        if(svrConfig != null) {
            NetworkConfig nwc = svrConfig.getNetworkConfig();
            if (nwc != null) {
                List<NetworkListener> lss = nwc.getNetworkListeners().getNetworkListener();
                if ( (lss != null) && (!lss.isEmpty()) ) {
                    for (NetworkListener ls : lss) {
                        if (ServerTags.ADMIN_LISTENER_ID.equals(ls.getName()) && ls.findThreadPool() != null) {
                            poolSize = Integer.parseInt(ls.findThreadPool().getMaxThreadPoolSize());
                        }
                    }
                }
            }
        }
        svc = Executors.newFixedThreadPool(poolSize, new InstanceStateThreadFactory());
    }

    public Future<InstanceCommandResult> submitJob(InstanceCommand ice, InstanceCommandResult r) {
        FutureTask<InstanceCommandResult> t = new FutureTask<InstanceCommandResult>((Runnable)ice, r);
        return svc.submit(t, r);
    }

    private static class InstanceStateThreadFactory implements ThreadFactory {
        @Override
        public Thread newThread(Runnable runnableObj) {
            Thread t = new Thread(runnableObj);
            t.setDaemon(true);
            return t;
        }
    }
}
